@@ -124,12 +124,25 @@ class DiscreteEnv(gym.Env):
     #extract theta parameters from the fitted logistic
     thetas1 = np.array([model1.coef_[0,0] , model1.coef_[0,1], model1.intercept_[0]])
     #extract theta parameter for Xa from the fitted logistic
-    theta_updated = np.array([model1.coef_[0,1]]) #thetas[1] coef for Xs, thetas[2] coef for Xa
+    #theta_updated = np.array([model1.coef_[0,1]]) #thetas[1] coef for Xs, thetas[2] coef for Xa
     
-    Z1 = ((thetas1[0])+(thetas1[1])*(df_new["Xs"])+(thetas1[2])*(df_new["Xa"]))
-    Prob1 = np.exp(Z1)/(1+np.exp(Z1)) #P(Y=1)
+    list1= []
+    for i in df_new.itertuples(index=False):
+      Xss = i[0] #no change
+      Xaa = i[1] #no change
+      YY = i[2] #no change
 
-    self.Ynew_cumul = np.mean(Prob1)
+      Z1 = ((thetas1[0])+(thetas1[1])*(Xss)+(thetas1[2])*(Xaa))
+      Prob1 = np.exp(Z1)/(1+np.exp(Z1)) #P(Y=1)
+      list1.append([Xss, Xaa, YY, Prob1])
+
+    list_new = pd.DataFrame(list1, columns=['Xs', 'Xa', 'Y', 'Prob1']) 
+    self.Ynew_cumul = np.mean(list_new[["Prob1"]])
+    
+     
+    #Z1 = ((thetas1[0])+(thetas1[1])*(df_new["Xs"])+(thetas1[2])*(df_new["Xa"]))
+    #Prob1 = np.exp(Z1)/(1+np.exp(Z1)) #P(Y=1)
+    #self.Ynew_cumul = np.mean(Prob1)
     
     #check if horizon is over, otherwise keep on going
     if self.horizon <= 0:
@@ -146,7 +159,7 @@ class DiscreteEnv(gym.Env):
     #set placeholder for infos
     info ={}        
      
-    return self.state, reward, done, theta_updated , {}
+    return self.state, reward, thetas1, done , {}
 
 #reset state and horizon    
   def reset(self):
